@@ -5,10 +5,9 @@ from zlib import crc32
 
 import numpy as np
 import pytest
-import six
 
 from distributed.protocol import (serialize, deserialize, decompress, dumps,
-        loads, to_serialize, msgpack)
+                                  loads, to_serialize, msgpack)
 from distributed.protocol.utils import BIG_BYTES_SHARD_SIZE
 from distributed.utils import tmpfile, nbytes
 from distributed.utils_test import slow, gen_cluster
@@ -29,40 +28,41 @@ def test_serialize():
 
 
 @pytest.mark.parametrize('x',
-        [np.ones(5),
-         np.array(5),
-         np.random.random((5, 5)),
-         np.random.random((5, 5))[::2, :],
-         np.random.random((5, 5))[:, ::2],
-         np.asfortranarray(np.random.random((5, 5))),
-         np.asfortranarray(np.random.random((5, 5)))[::2, :],
-         np.asfortranarray(np.random.random((5, 5)))[:, ::2],
-         np.random.random(5).astype('f4'),
-         np.random.random(5).astype('>i8'),
-         np.random.random(5).astype('<i8'),
-         np.arange(5).astype('M8[us]'),
-         np.arange(5).astype('M8[ms]'),
-         np.arange(5).astype('m8'),
-         np.arange(5).astype('m8[s]'),
-         np.arange(5).astype('c16'),
-         np.arange(5).astype('c8'),
-         np.array([True, False, True]),
-         np.ones(shape=5, dtype=[('a', 'i4'), ('b', 'M8[us]')]),
-         np.array(['abc'], dtype='S3'),
-         np.array(['abc'], dtype='U3'),
-         np.array(['abc'], dtype=object),
-         np.ones(shape=(5,), dtype=('f8', 32)),
-         np.ones(shape=(5,), dtype=[('x', 'f8', 32)]),
-         np.ones(shape=(5,), dtype=np.dtype([('a', 'i1'), ('b', 'f8')], align=False)),
-         np.ones(shape=(5,), dtype=np.dtype([('a', 'i1'), ('b', 'f8')], align=True)),
-         np.ones(shape=(5,), dtype=np.dtype([('a', 'm8[us]')], align=False)),
-         np.ones(shape=(5,), dtype=np.dtype([('a', 'm8')], align=False)),  # this dtype fails unpickling
-         np.array([(1, 'abc')], dtype=[('x', 'i4'), ('s', object)]),
-         np.zeros(5000, dtype=[('x%d'%i,'<f8') for i in range(4)]),
-         np.zeros(5000, dtype='S32'),
-         np.zeros((1, 1000, 1000)),
-         np.arange(12)[::2],  # non-contiguous array
-         np.ones(shape=(5, 6)).astype(dtype=[('total', '<f8'), ('n', '<f8')])])
+                         [np.ones(5),
+                          np.array(5),
+                             np.random.random((5, 5)),
+                             np.random.random((5, 5))[::2, :],
+                             np.random.random((5, 5))[:, ::2],
+                             np.asfortranarray(np.random.random((5, 5))),
+                             np.asfortranarray(np.random.random((5, 5)))[::2, :],
+                             np.asfortranarray(np.random.random((5, 5)))[:, ::2],
+                             np.random.random(5).astype('f4'),
+                             np.random.random(5).astype('>i8'),
+                             np.random.random(5).astype('<i8'),
+                             np.arange(5).astype('M8[us]'),
+                             np.arange(5).astype('M8[ms]'),
+                             np.arange(5).astype('m8'),
+                             np.arange(5).astype('m8[s]'),
+                             np.arange(5).astype('c16'),
+                             np.arange(5).astype('c8'),
+                             np.array([True, False, True]),
+                             np.ones(shape=5, dtype=[('a', 'i4'), ('b', 'M8[us]')]),
+                             np.array(['abc'], dtype='S3'),
+                             np.array(['abc'], dtype='U3'),
+                             np.array(['abc'], dtype=object),
+                             np.ones(shape=(5,), dtype=('f8', 32)),
+                             np.ones(shape=(5,), dtype=[('x', 'f8', 32)]),
+                             np.ones(shape=(5,), dtype=np.dtype([('a', 'i1'), ('b', 'f8')], align=False)),
+                             np.ones(shape=(5,), dtype=np.dtype([('a', 'i1'), ('b', 'f8')], align=True)),
+                             np.ones(shape=(5,), dtype=np.dtype([('a', 'm8[us]')], align=False)),
+                             # this dtype fails unpickling
+                             np.ones(shape=(5,), dtype=np.dtype([('a', 'm8')], align=False)),
+                             np.array([(1, 'abc')], dtype=[('x', 'i4'), ('s', object)]),
+                             np.zeros(5000, dtype=[('x%d' % i, '<f8') for i in range(4)]),
+                             np.zeros(5000, dtype='S32'),
+                             np.zeros((1, 1000, 1000)),
+                             np.arange(12)[::2],  # non-contiguous array
+                             np.ones(shape=(5, 6)).astype(dtype=[('total', '<f8'), ('n', '<f8')])])
 def test_dumps_serialize_numpy(x):
     header, frames = serialize(x)
     if 'compression' in header:
@@ -132,7 +132,7 @@ def test_dumps_serialize_numpy_large():
                                      ([('a', 'i4'), ('b', 'f8')], 12),
                                      (('i4', 100), 4),
                                      ([('a', 'i4', 100)], 8),
-                                     ([('a', 'i4', 20), ('b', 'f8')], 20*4 + 8),
+                                     ([('a', 'i4', 20), ('b', 'f8')], 20 * 4 + 8),
                                      ([('a', 'i4', 200), ('b', 'f8')], 8)])
 def test_itemsize(dt, size):
     assert itemsize(np.dtype(dt)) == size
@@ -148,7 +148,7 @@ def test_compress_numpy():
 
     header = msgpack.loads(frames[2], encoding='utf8', use_list=False)
     try:
-        import blosc
+        import blosc  # noqa: F401
     except ImportError:
         pass
     else:
@@ -156,7 +156,6 @@ def test_compress_numpy():
                    header['headers'][('x',)]['compression'])
 
 
-
 def test_compress_memoryview():
     mv = memoryview(b'0' * 1000000)
     compression, compressed = maybe_compress(mv)
@@ -177,7 +176,6 @@ def test_dont_compress_uncompressable_data():
     assert header['compression'] == ['blosc']
     assert data != x.data
 
-
     x = np.ones(100)
     header, [data] = serialize(x)
     assert 'compression' not in header
@@ -198,7 +196,7 @@ def test_compression_takes_advantage_of_itemsize():
     x = np.arange(1000000, dtype='i8')
 
     assert (len(blosc.compress(x.data, typesize=8))
-          < len(blosc.compress(x.data, typesize=1)))
+            < len(blosc.compress(x.data, typesize=1)))
 
     _, a = serialize(x)
     aa = [maybe_compress(frame)[1] for frame in a]
