@@ -181,7 +181,7 @@ def test_upload_file(c, s, a, b):
     assert not os.path.exists(os.path.join(a.local_dir, 'foobar.py'))
 
 
-@pytest.mark.xfail(reason="don't yet support uploading pyc files")
+@pytest.mark.skip(reason="don't yet support uploading pyc files")
 @gen_cluster(client=True, ncores=[('127.0.0.1', 1)])
 def test_upload_file_pyc(c, s, w):
     with tmpfile() as dirname:
@@ -564,7 +564,7 @@ def test_clean_nbytes(c, s, a, b):
 
 @gen_cluster(client=True, ncores=[('127.0.0.1', 1)] * 20)
 def test_gather_many_small(c, s, a, *workers):
-    a.total_connections = 2
+    a.total_out_connections = 2
     futures = yield c._scatter(list(range(100)))
 
     assert all(w.data for w in workers)
@@ -705,21 +705,6 @@ def test_stop_doing_unnecessary_work(c, s, a, b):
 
 @gen_cluster(client=True, ncores=[('127.0.0.1', 1)])
 def test_priorities(c, s, w):
-    a = delayed(slowinc)(1, dask_key_name='a', delay=0.05)
-    b = delayed(slowinc)(2, dask_key_name='b', delay=0.05)
-    a1 = delayed(slowinc)(a, dask_key_name='a1', delay=0.05)
-    a2 = delayed(slowinc)(a1, dask_key_name='a2', delay=0.05)
-    b1 = delayed(slowinc)(b, dask_key_name='b1', delay=0.05)
-
-    z = delayed(add)(a2, b1)
-    future = yield c.compute(z)
-
-    log = [t for t in w.log if t[1] == 'executing' and t[2] == 'memory']
-    assert [t[0] for t in log[:5]] == ['a', 'b', 'a1', 'b1', 'a2']
-
-
-@gen_cluster(client=True, ncores=[('127.0.0.1', 1)])
-def test_priorities_2(c, s, w):
     values = []
     for i in range(10):
         a = delayed(slowinc)(i, dask_key_name='a-%d' % i, delay=0.01)
@@ -755,8 +740,7 @@ def test_worker_dir(worker):
     with tmpfile() as fn:
         @gen_cluster(client=True, worker_kwargs={'local_dir': fn})
         def test_worker_dir(c, s, a, b):
-            directories = [info['local_directory']
-                           for info in s.worker_info.values()]
+            directories = [w.local_directory for w in s.workers.values()]
             assert all(d.startswith(fn) for d in directories)
             assert len(set(directories)) == 2  # distinct
 
@@ -832,7 +816,7 @@ def test_fail_write_many_to_disk(c, s, a):
 
 @gen_cluster()
 def test_pid(s, a, b):
-    assert s.worker_info[a.address]['pid'] == os.getpid()
+    assert s.workers[a.address].pid == os.getpid()
 
 
 @gen_cluster(client=True)
@@ -1162,3 +1146,133 @@ def test_scheduler_address_config(c, s):
         yield worker._start()
         assert worker.scheduler.address == s.address
     yield worker._close()
+
+
+@slow
+@gen_cluster(client=True)
+def test_wait_for_outgoing(c, s, a, b):
+    np = pytest.importorskip('numpy')
+    x = np.random.random(10000000)
+    future = yield c.scatter(x, workers=a.address)
+
+    y = c.submit(inc, future, workers=b.address)
+    yield wait(y)
+
+    assert len(b.incoming_transfer_log) == len(a.outgoing_transfer_log) == 1
+    bb = b.incoming_transfer_log[0]['duration']
+    aa = a.outgoing_transfer_log[0]['duration']
+    ratio = aa / bb
+
+    assert 1 / 3 < ratio < 3
+
+
+@pytest.mark.skipif(not sys.platform.startswith('linux'),
+                    reason="Need 127.0.0.2 to mean localhost")
+@gen_cluster(ncores=[('127.0.0.1', 1), ('127.0.0.1', 1), ('127.0.0.2', 1)],
+             client=True)
+def test_prefer_gather_from_local_address(c, s, w1, w2, w3):
+    x = yield c.scatter(123, workers=[w1.address, w3.address], broadcast=True)
+
+    y = c.submit(inc, x, workers=[w2.address])
+    yield wait(y)
+
+    assert any(d['who'] == w2.address for d in w1.outgoing_transfer_log)
+    assert not any(d['who'] == w2.address for d in w3.outgoing_transfer_log)
+
+
+@gen_cluster(client=True, ncores=[('127.0.0.1', 1)] * 20, timeout=30,
+             config={'distributed.worker.connections.incoming': 1})
+def test_avoid_oversubscription(c, s, *workers):
+    np = pytest.importorskip('numpy')
+    x = c.submit(np.random.random, 1000000, workers=[workers[0].address])
+    yield wait(x)
+
+    futures = [c.submit(len, x, pure=False, workers=[w.address])
+               for w in workers[1:]]
+
+    yield wait(futures)
+
+    # Original worker not responsible for all transfers
+    assert len(workers[0].outgoing_transfer_log) < len(workers) - 2
+
+    # Some other workers did some work
+    assert len([w for w in workers if len(w.outgoing_transfer_log) > 0]) >= 3
+
+
+@gen_cluster(client=True, worker_kwargs={'metrics': {'my_port': lambda w: w.port}})
+def test_custom_metrics(c, s, a, b):
+    assert s.workers[a.address].metrics['my_port'] == a.port
+    assert s.workers[b.address].metrics['my_port'] == b.port
+
+
+@gen_cluster(client=True)
+def test_register_worker_callbacks(c, s, a, b):
+    #preload function to run
+    def mystartup(dask_worker):
+        dask_worker.init_variable = 1
+
+    def mystartup2():
+        import os
+        os.environ['MY_ENV_VALUE'] = 'WORKER_ENV_VALUE'
+        return "Env set."
+
+    #Check that preload function has been run
+    def test_import(dask_worker):
+        return hasattr(dask_worker, 'init_variable')
+        #       and dask_worker.init_variable == 1
+
+    def test_startup2():
+        import os
+        return os.getenv('MY_ENV_VALUE', None) == 'WORKER_ENV_VALUE'
+
+    # Nothing has been run yet
+    assert len(s.worker_setups) == 0
+    result = yield c.run(test_import)
+    assert list(result.values()) == [False] * 2
+    result = yield c.run(test_startup2)
+    assert list(result.values()) == [False] * 2
+
+    # Start a worker and check that startup is not run
+    worker = Worker(s.address, loop=s.loop)
+    yield worker._start()
+    result = yield c.run(test_import, workers=[worker.address])
+    assert list(result.values()) == [False]
+    yield worker._close()
+
+    # Add a preload function
+    response = yield c.register_worker_callbacks(setup=mystartup)
+    assert len(response) == 2
+    assert len(s.worker_setups) == 1
+
+    # Check it has been ran on existing worker
+    result = yield c.run(test_import)
+    assert list(result.values()) == [True] * 2
+
+    # Start a worker and check it is ran on it
+    worker = Worker(s.address, loop=s.loop)
+    yield worker._start()
+    result = yield c.run(test_import, workers=[worker.address])
+    assert list(result.values()) == [True]
+    yield worker._close()
+
+    # Register another preload function
+    response = yield c.register_worker_callbacks(setup=mystartup2)
+    assert len(response) == 2
+    assert len(s.worker_setups) == 2
+
+    # Check it has been run
+    result = yield c.run(test_startup2)
+    assert list(result.values()) == [True] * 2
+
+    # Start a worker and check it is ran on it
+    worker = Worker(s.address, loop=s.loop)
+    yield worker._start()
+    result = yield c.run(test_import, workers=[worker.address])
+    assert list(result.values()) == [True]
+    result = yield c.run(test_startup2, workers=[worker.address])
+    assert list(result.values()) == [True]
+    yield worker._close()
+
+    # Final exception test
+    with pytest.raises(ZeroDivisionError):
+        yield c.register_worker_callbacks(setup=lambda: 1 / 0)
